==> readmeter-3.1.3.jar: readmeter/sqls/recordHistory/handRecordList.sql <==
select * from (
                  SELECT
                      --h.f_userfiles_id,
                      h.id hand_id,
                      h.f_operatorid,
                      h.f_result_state,
                      h.f_last_tablebase,
                      h.f_operator f_handoperator,
                      isnull(mb.f_inputtor,h.f_inputtor) f_inputtor,
                      convert(VARCHAR(100),h.f_last_input_date,23) f_last_input_date,
                      h.f_tablebase,
                      h.f_oughtamount,
                      h.f_oughtfee,
                      h.f_balance,
                      h.f_hand_date,
                      h.f_meter_classify,
                      h.f_meternumber,
                      h.f_whether_pay,
                      h.f_meter_state,
                      h.f_curbalance,
                      convert(VARCHAR(100),h.f_input_date,23) f_input_date,
                      f_input_date input_date,
                      s.id sell_id,
                      h.f_orgid,
                      s.f_operator f_selloperator,
                      s.f_operate_date,
                      ui.f_user_name,
                      ui.f_book_no,
                      ui.f_userinfo_code,
                      isnull(s.f_collection,0) f_collection,
                      case when f_whether_pay='否' then isnull(f_oughtfee,0)-isnull(f_debt_money,0) else 0 end f_hand_oughtfee
                  FROM
                      t_handplan h
                          left join t_meter_book mb on h.f_meter_book_num=mb.id
                          LEFT JOIN (select * from t_sellinggas where f_state='有效') s ON h.f_sell_id = s.id
                          LEFT JOIN (select f_hand_id,sum(f_debt_money) f_debt_money from t_sellinghand group by f_hand_id) sh on h.id=sh.f_hand_id
                          LEFT JOIN t_userinfo ui ON h.f_userinfo_id= ui.f_userinfo_id
                  WHERE
                          h.f_hand_state = '有效' and h.f_meter_state<>'未抄表'
              union all
               SELECT
                      --c.f_userfiles_id,
                      c.id hand_id,
                      c.f_operatorid,
                      c.f_result_state,
                      c.f_last_tablebase,
                      c.f_operator f_handoperator,
                      c.f_inputtor,
                      convert(VARCHAR(100),c.f_last_input_date,23) f_last_input_date,
                      c.f_tablebase,
                      c.f_real_amount,
                      c.f_real_fee,
                      c.f_balance,
                      c.f_hand_date,
                      c.f_meter_classify,
                      c.f_meternumber,
                      '' f_whether_pay,
                      c.f_meter_state,
                      c.f_curbalance,
                      convert(VARCHAR(100),c.f_input_date,23) f_input_date,
                      f_input_date input_date,
                      null sell_id,
                      c.f_orgid,
                      '' f_selloperator,
                      null f_operate_date,
                      ui.f_user_name,
                      ui.f_book_no,
                      ui.f_userinfo_code,
                      0 f_collection,
                      0 f_hand_oughtfee
                  FROM
                      t_cardhand c
                          LEFT JOIN t_userinfo ui ON c.f_userinfo_id= ui.f_userinfo_id
              )t
where {condition}
order by hand_id

==> readmeter-3.1.10.jar: readmeter/sqls/recordHistory/handRecordList.sql <==
select * from (
                  SELECT
                      --h.f_userfiles_id,
                      h.id hand_id,
                      h.f_operatorid,
                      h.f_result_state,
                      h.f_last_tablebase,
                      h.f_operator f_handoperator,
                      isnull(mb.f_inputtor,h.f_inputtor) f_inputtor,
                      convert(VARCHAR(100),h.f_last_input_date,23) f_last_input_date,
                      h.f_tablebase,
                      h.f_oughtamount,
                      h.f_oughtfee,
                      h.f_balance,
                      h.f_hand_date,
                      h.f_input_date,
                      h.f_meter_classify,
                      h.f_meternumber,
                      h.f_whether_pay,
                      h.f_meter_state,
                      h.f_curbalance,
                      h.f_address,
--                       convert(VARCHAR(100),h.f_input_date,23) f_input_date,
                      f_input_date input_date,
                      s.id sell_id,
                      h.f_orgid,
                      s.f_operator f_selloperator,
                      s.f_operate_date,
                      ui.f_user_name,
                      ui.f_book_no,
                      ui.f_userinfo_code,
                      isnull(s.f_collection,0) f_collection,
                      case when f_whether_pay='否' then isnull(f_oughtfee,0)-isnull(f_debt_money,0) else 0 end f_hand_oughtfee
                  FROM
                      t_handplan h
                          left join t_meter_book mb on h.f_meter_book_num=mb.id
                          LEFT JOIN (select * from t_sellinggas where f_state='有效') s ON h.f_sell_id = s.id
                          LEFT JOIN (select f_hand_id,sum(f_debt_money) f_debt_money from t_sellinghand group by f_hand_id) sh on h.id=sh.f_hand_id
                          LEFT JOIN t_userinfo ui ON h.f_userinfo_id= ui.f_userinfo_id
                  WHERE
                          h.f_hand_state = '有效' and h.f_meter_state<>'未抄表'
              union all
               SELECT
                      --c.f_userfiles_id,
                      c.id hand_id,
                      c.f_operatorid,
                      c.f_result_state,
                      c.f_last_tablebase,
                      c.f_operator f_handoperator,
                      c.f_inputtor,
                      convert(VARCHAR(100),c.f_last_input_date,23) f_last_input_date,
                      c.f_tablebase,
                      c.f_real_amount,
                      c.f_real_fee,
                      c.f_balance,
                      c.f_hand_date,
                      c.f_input_date,
                      c.f_meter_classify,
                      c.f_meternumber,
                      '' f_whether_pay,
                      c.f_meter_state,
                      c.f_curbalance,
                      c.f_address,
--                       convert(VARCHAR(100),c.f_input_date,23) f_input_date,
                      f_input_date input_date,
                      null sell_id,
                      c.f_orgid,
                      '' f_selloperator,
                      null f_operate_date,
                      ui.f_user_name,
                      ui.f_book_no,
                      ui.f_userinfo_code,
                      0 f_collection,
                      0 f_hand_oughtfee
                  FROM
                      t_cardhand c
                          LEFT JOIN t_userinfo ui ON c.f_userinfo_id= ui.f_userinfo_id
              )t
where {condition}
order by input_date
